summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/cps3.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/cps3.cpp')
-rw-r--r--src/mame/audio/cps3.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/cps3.cpp b/src/mame/audio/cps3.cpp
index f800aa0e598..aa7eb8340f0 100644
--- a/src/mame/audio/cps3.cpp
+++ b/src/mame/audio/cps3.cpp
@@ -39,7 +39,7 @@ cps3_sound_device::cps3_sound_device(const machine_config &mconfig, const char *
void cps3_sound_device::device_start()
{
/* Allocate the stream */
- m_stream = stream_alloc(0, 2, clock() / 384);
+ m_stream = stream_alloc_legacy(0, 2, clock() / 384);
save_item(NAME(m_key));
for (int i = 0; i < 16; i++)
@@ -52,10 +52,10 @@ void cps3_sound_device::device_start()
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void cps3_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void cps3_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
/* Clear the buffers */
memset(outputs[0], 0, samples*sizeof(*outputs[0]));
@@ -52,10 +52,10 @@ void cps3_sound_device::device_start()
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------